<?php
/*
 Plugin Name: Princess Alexis Biography
 Plugin URI: https://blog.tremlas.com/wordpress-plugins/alexis-biography-plugin-details/
 Description: Adds a Biography of Princess Alexis as a shortcode
 Version: 3.108.0
 Author: David Vines
 Author URI: http://tremlas.com
 License:  Creative Commons License
 */
/* © Copyright 2017, 2021 David Vines

Creative Commons License

This work is licensed under a Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License.
*/

// Debugging function in case we need it
if ( !function_exists('djv_write_log') ) {
	function djv_write_log ( $log )  {
		if ( true === WP_DEBUG ) {
			if ( is_array( $log ) || is_object( $log ) ) {
				error_log( print_r( $log, true ) );
			} else {
				error_log( $log );
			}
		}
	}
}

/** 
 * Shortcode to add the version of the plugin
 */
function djv_princessAlexisBiographyVersion_shortcode() {
	return 'Princess Alexis Biography Version 3.108.0';
}
add_shortcode( 'alexisBiographyVersion', 'djv_princessAlexisBiographyVersion_shortcode' );

/**
 * Shortcode to add a biography of Princess Alexis
 */

// Now for a shortcode that can be used to get links and/or tables for the characters
function djv_princessAlexisBiography_shortcode( $attr, $content = null ) {

	$plugin_url = plugin_dir_url(__FILE__);
	wp_enqueue_script('djv_alexisbio_js', $plugin_url.'js/alexis.js', [],'',true );
	wp_enqueue_style('djv_alexisbio_css', $plugin_url.'css/alexisbio.css');
	
	static $id = 0; $id++;

	$text  = '' . PHP_EOL;

	$file = plugin_dir_path(__FILE__);
	$filecontent = file_get_contents($file.'/html/bio.html');
	$filecontent = str_replace('@@@ID@@@', $id, $filecontent );
	
	$text .= $filecontent . PHP_EOL;
	
	$text .= '<script type="text/javascript">' . PHP_EOL;
	$text .= 'var options = options || {};' . PHP_EOL;
	$text .= 'options.ids = options.ids || [];' . PHP_EOL;
	$text .= 'options.ids.push(' . $id . ');' . PHP_EOL;
	$text .= '</script>' . PHP_EOL;
	
	return $text;
}

add_shortcode( 'alexisBiography', 'djv_princessAlexisBiography_shortcode' );

/* --------------------- Functions for updating plugins ------------------------------ */
function djv_PrincessAlexisBiography_get_remote_update_from( $urlbase, $slug ) {
 $url = $urlbase . '/wp-content/uploads/jsons/' . $slug . '.json';
 $remote =  wp_remote_get( $url, array( 'timeout' => 10, 'headers' => array( 'Accept' => 'application/json' ) ) );
 if ( !is_wp_error( $remote ) && isset( $remote['response']['code'] ) && 200 == $remote['response']['code'] && ! empty( $remote['body'] ) ) {
  $remote['urlbase'] = $urlbase;
 }
 return $remote;
}
function djv_PrincessAlexisBiography_get_remote_update_info( $slug ) {
 $remote = get_transient( 'djv_update_' . $slug );
 if (false == $remote) {
  if ( 'cubi' == gethostname() ) {
   $remote = djv_PrincessAlexisBiography_get_remote_update_from( 'http://cubi.internal', $slug );
   if (false !== $remote) {
    set_transient( 'djv_update_' . $slug, $remote, 10 ); // Save for only 10 seconds here
   }
  }
 }
 if (false == $remote || is_wp_error($remote) || !isset( $remote['response']['code'] ) || 200 !== $remote['response']['code'] || empty( $remote['body'] ) ) {
  $remote = djv_PrincessAlexisBiography_get_remote_update_from( 'https://blog.tremlas.com', $slug );
  set_transient( 'djv_update_' . $slug, $remote, 43200 ); // Save for 12 hours
 }
 if ( !is_wp_error( $remote ) && isset( $remote['response']['code'] ) && 200 == $remote['response']['code'] && ! empty( $remote['body'] ) ) {
  $body = json_decode( $remote['body'] );
  $info = new StdClass();
  $info->name = 'Princess Alexis Biography';
  $info->slug = $slug;
  $info->version = $body->version;
  $info->requires = $body->requires;
  $info->author = '<a href="' . $body->author_profile . '">' . $body->author . '</a>';
  $info->download_link = $remote['urlbase'] . '/' . $body->download_url;
  $info->trunk = $remote['urlbase'] . '/' . $body->download_url;
  $info->last_updated = $body->last_updated;
  $info->sections = array(
    'description'  => implode( "\n", $body->sections->description ),
    'installation' => implode( "\n", $body->sections->installation ),
    'changelog'    => implode( "\n", $body->sections->changelog ),
  );
  $info->homepage = $remote['urlbase'] . '/' . $body->homepage;
  return $info;
 }
 return false;
}

function djv_PrincessAlexisBiography_check_for_update( $name, $slug ) {
 $info = djv_PrincessAlexisBiography_get_remote_update_info( $slug );
 if ( false == $info ) {
  return false;
 }
 if ( version_compare( '3.108.0', $info->version, '<' ) && version_compare( $info->requires, get_bloginfo( 'version' ), '<' ) ) {
  $update = (object) array(
    'id'            => $name,
    'slug'          => $slug,
    'plugin'        => $name,
    'new_version'   => $info->version,
    'url'           => $info->homepage,
    'package'       => $info->download_link,
    'icons'         => array(),
    'banners'       => array(),
    'banners_rtl'   => array(),
    'tested'        => '',
    'requires_php'  => '',
    'compatability' => new StdClass()
  );
  return $update;
 } else {
  return false;
 }
}

function djv_PrincessAlexisBiography_pre_set_site_transient_update_plugins( $transient ) {
 // Check for update
 $pluginphp = 'PrincessBiography/PrincessBiographyPlugin.php';
 $pluginslug = 'PrincessBiography';
 $update = djv_PrincessAlexisBiography_check_for_update( $pluginphp, $pluginslug );
 if ( $update ) {
  $transient->response[$pluginphp] = $update;
 } else {
  // No update
  $item = (object) array(
    'id'            => $pluginphp,
    'slug'          => $pluginslug,
    'plugin'        => $pluginphp,
    'new_version'   => '3.108.0',
    'url'           => '',
    'package'       => '',
    'icons'         => array(),
    'banners'       => array(),
    'banners_rtl'   => array(),
    'tested'        => '',
    'requires_php'  => '',
    'compatability' => new StdClass()
  );
  $transient->no_update[$pluginphp] = $item;
 }
 return $transient;
}
add_filter( 'pre_set_site_transient_update_plugins', 'djv_PrincessAlexisBiography_pre_set_site_transient_update_plugins' );

function djv_PrincessAlexisBiography_plugin_info( $result, $action, $args ) {
 $slug = 'PrincessBiography';
 if ( 'plugin_information' !== $action ) {
  return $result;
 }
 if ( $slug !== $args->slug) {
  return $result;
 }
 return djv_PrincessAlexisBiography_get_remote_update_info( $slug );
}
add_filter( 'plugins_api', 'djv_PrincessAlexisBiography_plugin_info', 10, 3 );

?>